PushBack

Trait PushBack 

pub trait PushBack: Collection {
    type Output;

    // Required method
    fn push_back(&mut self, element: Self::Item) -> Self::Output;
}
Mutable collection where new elements can be pushed on the back.

Required Associated Types

type Output

The output of the push function.

Required Methods

fn push_back(&mut self, element: Self::Item) -> Self::Output

Push a new element on the back of the collection.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> PushBack for Vec<T>

Source

type Output = ()

Source

fn push_back(&mut self, t: T)

Source

impl<T> PushBack for VecDeque<T>

Source

type Output = ()

Source

fn push_back(&mut self, t: T)

Implementors