pub trait PushFront: Collection {
type Output;
// Required method
fn push_front(&mut self, element: Self::Item) -> Self::Output;
}Expand description
Mutable collection where new elements can be pushed on the front.
Required Associated Types
Required Methods
Sourcefn push_front(&mut self, element: Self::Item) -> Self::Output
fn push_front(&mut self, element: Self::Item) -> Self::Output
Push a new element on the front of the collection.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".